package com.fr.plugin.third.party.jsdbahfc.web;

import com.fr.decision.config.AppearanceConfig;
import com.fr.plugin.context.PluginContexts;
import com.fr.plugin.third.party.jsdbahfc.ThemeConstants;
import com.fr.plugin.third.party.jsdbahfc.Utils;
import com.fr.web.struct.Component;
import com.fr.web.struct.Filter;
import com.fr.web.struct.browser.RequestClient;
import com.fr.web.struct.category.ParserType;
import com.fr.web.struct.category.ScriptPath;
import com.fr.web.struct.category.StylePath;

public class MainFilesComponent extends Component {
    public static final MainFilesComponent KEY = new MainFilesComponent();
    private MainFilesComponent(){}
    /**
     * 返回需要引入的JS脚本路径
     * @param client 请求客户端描述
     * @return JS脚本路径
     */
    @Override
    public ScriptPath script(RequestClient client ) {
        //如果不需要就直接返回  ScriptPath.EMPTY
        return ScriptPath.build("com/fr/plugin/third/party/jsdbahfc/web/main.js");
    }

    /**
     * 返回需要引入的CSS样式路径
     * @param client 请求客户端描述
     * @return CSS样式路径
     */
    @Override
    public StylePath style(RequestClient client ) {
        //如果不需要就直接返回 StylePath.EMPTY;
        return StylePath.build("com/fr/plugin/third/party/jsdbahfc/web/main.css", ParserType.DYNAMIC);
    }

    /**
     * 通过给定的资源过滤器控制是否加载这个资源
     * @return 资源过滤器
     */
    @Override
    public Filter filter() {
        return new Filter(){
            @Override
            public boolean accept() {
                Utils.logFunction();
                if (!PluginContexts.currentContext().isAvailable()) {
                    return false;
                }
                String loginPageId = AppearanceConfig.getInstance().getThemeId();
                return ThemeConstants.PLUGIN_ID.equals(loginPageId);
            }
        };
    }
}